@@ -6,7 +6,7 @@
 #
 
 package File::ByLine;
-$File::ByLine::VERSION = '1.181981'; # TRIAL
+$File::ByLine::VERSION = '1.182360'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Line-by-line file access loops
@@ -32,11 +32,11 @@ our @ISA = qw(Exporter);
 
 ## no critic (Modules::ProhibitAutomaticExportation)
 our @EXPORT =
-  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines);
+  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile);
 ## use critic
 
 our @EXPORT_OK =
-  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines);
+  qw(dolines forlines greplines maplines parallel_dolines parallel_forlines parallel_greplines parallel_maplines readlines writefile);
 
 
 sub dolines (&$) {
@@ -137,6 +137,23 @@ sub readlines ($) {
     return $OBJ->lines($file);
 }
 
+
+sub writefile ($@) {
+    my ( $file, @lines ) = @_;
+    if ( !defined($file) ) { die("Must define the filename"); }
+
+    # Last line should have it's newline removed, if applicable
+    if (@lines) { $lines[-1] =~ s/\n$//s; }
+
+    open my $fh, '>', $file;
+    foreach my $line (@lines) {
+        say $fh $line;
+    }
+    close $fh;
+
+    return;
+}
+
 #
 # Object Oriented Interface
 #
@@ -162,7 +179,7 @@ File::ByLine - Line-by-line file access loops
 
 =head1 VERSION
 
-version 1.181981
+version 1.182360
 
 =head1 SYNOPSIS
 
@@ -194,9 +211,11 @@ version 1.181981
   # Read an entire file, split into lines
   my (@result) = readlines "file.txt";
 
+  # Write out a file
+  writefile "file.txt", @lines;  # Since version 2.182360
 
   #
-  # Functional Interface
+  # Object Oriented Interface (More Powerful!)
   #
 
   # Execute a routine for each line of a file
@@ -234,7 +253,7 @@ version 1.181981
   my (@map_result)  = $byline->map( sub { lc($_) }, "file.txt");
 
   # Read an entire file, split into lines
-  my (@result) = readlines "file.txt";
+  my (@result) = $byline->lines("file.txt");
 
   # Alternative way of specifying filenames
   my $byline = File::ByLine->new();
@@ -480,6 +499,29 @@ Otherwise, this function is identical to C<maplines()>.
 This function simply returns an array of lines (without newlines) read from
 a file.
 
+=head2 writefile
+
+  writefile "file.txt", @lines;
+
+This was added in version 2.181850.
+
+This function creates a file (overwriting existing files) and writes each
+line to the file.  Each line (array element) is terminated with a newline,
+except the last line IF the last line ends in a newline itself.
+
+I.E. the following will write a file with three lines, each terminated by
+a newline:
+
+  writefile "file.txt", "a", "b", "c";
+
+So will this:
+
+  writefile "file.txt", "a\nb", "c\n";
+
+There is no object-oriented equivilent to this function.
+
+This does not return any value.
+
 =head1 OBJECT ORIENTED INTERFACE
 
 The object oriented interface was implemented in version 1.181860.
@@ -703,6 +745,22 @@ others won't (L<cpan> often, but not always, will; L<cpanm> will not by
 default).  In the cases where it is not automatically installed, you need to
 install L<Parallel::WorkUnit> to get this functionality.
 
+=head1 EXPRESSING APPRECIATION
+
+If this module makes your life easier, or helps make you (or your workplace)
+a ton of money, I always enjoy hearing about it!  My response when I hear that
+someone uses my module is to go back to that module and spend a little time on
+it if I think there's something to improve - it's motivating when you hear
+someone appreciates your work!
+
+I don't seek any money for this - I do this work because I enjoy it.  That
+said, should you want to show appreciation financially, few things would make
+me smile more than knowing that you sent a donation to the Gender Identity
+Center of Colorado (See L<http://giccolorado.org/> and donation page
+at L<https://tinyurl.com/giccodonation>).  This organization understands
+TIMTOWTDI in life and, in line with that understanding, provides life-saving
+support to the transgender community.
+
 =head1 AUTHOR
 
 Joelle Maslak <jmaslak@antelope.net>
